@@ -16,6 +16,7 @@ package com.google.api.client.http.apache.v2;
 
 import com.google.api.client.http.HttpMethods;
 import com.google.api.client.http.HttpTransport;
+import com.google.api.client.util.Beta;
 import java.io.IOException;
 import java.net.ProxySelector;
 import java.util.concurrent.TimeUnit;
@@ -29,7 +30,6 @@ import org.apache.http.client.methods.HttpPost;
 import org.apache.http.client.methods.HttpPut;
 import org.apache.http.client.methods.HttpRequestBase;
 import org.apache.http.client.methods.HttpTrace;
-import org.apache.http.config.SocketConfig;
 import org.apache.http.conn.ssl.SSLConnectionSocketFactory;
 import org.apache.http.impl.client.CloseableHttpClient;
 import org.apache.http.impl.client.HttpClientBuilder;
@@ -39,19 +39,15 @@ import org.apache.http.impl.conn.SystemDefaultRoutePlanner;
 /**
  * Thread-safe HTTP transport based on the Apache HTTP Client library.
  *
- * <p>
- * Implementation is thread-safe, as long as any parameter modification to the
- * {@link #getHttpClient() Apache HTTP Client} is only done at initialization time. For maximum
- * efficiency, applications should use a single globally-shared instance of the HTTP transport.
- * </p>
+ * <p>Implementation is thread-safe, as long as any parameter modification to the {@link
+ * #getHttpClient() Apache HTTP Client} is only done at initialization time. For maximum efficiency,
+ * applications should use a single globally-shared instance of the HTTP transport.
  *
- * <p>
- * Default settings are specified in {@link #newDefaultHttpClient()}. Use the
- * {@link #ApacheHttpTransport(HttpClient)} constructor to override the Apache HTTP Client used.
- * Please read the <a
+ * <p>Default settings are specified in {@link #newDefaultHttpClient()}. Use the {@link
+ * #ApacheHttpTransport(HttpClient)} constructor to override the Apache HTTP Client used. Please
+ * read the <a
  * href="http://hc.apache.org/httpcomponents-client-ga/tutorial/html/connmgmt.html">Apache HTTP
  * Client connection management tutorial</a> for more complex configuration options.
- * </p>
  *
  * @since 1.30
  * @author Yaniv Inbar
@@ -61,54 +57,79 @@ public final class ApacheHttpTransport extends HttpTransport {
   /** Apache HTTP client. */
   private final HttpClient httpClient;
 
+  /** If the HTTP client uses mTLS channel. */
+  private final boolean isMtls;
+
   /**
    * Constructor that uses {@link #newDefaultHttpClient()} for the Apache HTTP client.
    *
    * @since 1.30
    */
   public ApacheHttpTransport() {
-    this(newDefaultHttpClient());
+    this(newDefaultHttpClient(), false);
   }
 
   /**
    * Constructor that allows an alternative Apache HTTP client to be used.
    *
-   * <p>
-   * Note that in the previous version, we overrode several settings, however, we are no longer able
-   * to do so.
-   * </p>
+   * <p>Note that in the previous version, we overrode several settings. However, we are no longer
+   * able to do so.
+   *
+   * <p>If you choose to provide your own Apache HttpClient implementation, be sure that
    *
-   * <p>If you choose to provide your own Apache HttpClient implementation, be sure that</p>
    * <ul>
-   * <li>HTTP version is set to 1.1.</li>
-   * <li>Redirects are disabled (google-http-client handles redirects).</li>
-   * <li>Retries are disabled (google-http-client handles retries).</li>
+   *   <li>HTTP version is set to 1.1.
+   *   <li>Redirects are disabled (google-http-client handles redirects).
+   *   <li>Retries are disabled (google-http-client handles retries).
    * </ul>
    *
    * @param httpClient Apache HTTP client to use
-   *
    * @since 1.30
    */
   public ApacheHttpTransport(HttpClient httpClient) {
     this.httpClient = httpClient;
+    this.isMtls = false;
   }
 
   /**
-   * Creates a new instance of the Apache HTTP client that is used by the
-   * {@link #ApacheHttpTransport()} constructor.
+   * {@link Beta} <br>
+   * Constructor that allows an alternative Apache HTTP client to be used.
+   *
+   * <p>Note that in the previous version, we overrode several settings. However, we are no longer
+   * able to do so.
+   *
+   * <p>If you choose to provide your own Apache HttpClient implementation, be sure that
    *
-   * <p>
-   * Settings:
-   * </p>
    * <ul>
-   * <li>The client connection manager is set to {@link PoolingHttpClientConnectionManager}.</li>
-   * <li>The socket buffer size is set to 8192 using {@link SocketConfig}.</li>
-   * <li><The retry mechanism is turned off using
-   * {@link HttpClientBuilder#disableRedirectHandling}.</li>
-   * <li>The route planner uses {@link SystemDefaultRoutePlanner} with
-   * {@link ProxySelector#getDefault()}, which uses the proxy settings from <a
-   * href="http://docs.oracle.com/javase/7/docs/api/java/net/doc-files/net-properties.html">system
-   * properties</a>.</li>
+   *   <li>HTTP version is set to 1.1.
+   *   <li>Redirects are disabled (google-http-client handles redirects).
+   *   <li>Retries are disabled (google-http-client handles retries).
+   * </ul>
+   *
+   * @param httpClient Apache HTTP client to use
+   * @param isMtls If the HTTP client is mutual TLS
+   * @since 1.38
+   */
+  @Beta
+  public ApacheHttpTransport(HttpClient httpClient, boolean isMtls) {
+    this.httpClient = httpClient;
+    this.isMtls = isMtls;
+  }
+
+  /**
+   * Creates a new instance of the Apache HTTP client that is used by the {@link
+   * #ApacheHttpTransport()} constructor.
+   *
+   * <p>Settings:
+   *
+   * <ul>
+   *   <li>The client connection manager is set to {@link PoolingHttpClientConnectionManager}.
+   *   <li><The retry mechanism is turned off using {@link
+   *       HttpClientBuilder#disableRedirectHandling}.
+   *   <li>The route planner uses {@link SystemDefaultRoutePlanner} with {@link
+   *       ProxySelector#getDefault()}, which uses the proxy settings from <a
+   *       href="https://docs.oracle.com/javase/7/docs/api/java/net/doc-files/net-properties.html">system
+   *       properties</a>.
    * </ul>
    *
    * @return new instance of the Apache HTTP client
@@ -119,44 +140,35 @@ public final class ApacheHttpTransport extends HttpTransport {
   }
 
   /**
-   * Creates a new Apache HTTP client builder that is used by the
-   * {@link #ApacheHttpTransport()} constructor.
+   * Creates a new Apache HTTP client builder that is used by the {@link #ApacheHttpTransport()}
+   * constructor.
+   *
+   * <p>Settings:
    *
-   * <p>
-   * Settings:
-   * </p>
    * <ul>
-   * <li>The client connection manager is set to {@link PoolingHttpClientConnectionManager}.</li>
-   * <li>The socket buffer size is set to 8192 using {@link SocketConfig}.</li>
-   * <li><The retry mechanism is turned off using
-   * {@link HttpClientBuilder#disableRedirectHandling}.</li>
-   * <li>The route planner uses {@link SystemDefaultRoutePlanner} with
-   * {@link ProxySelector#getDefault()}, which uses the proxy settings from <a
-   * href="http://docs.oracle.com/javase/7/docs/api/java/net/doc-files/net-properties.html">system
-   * properties</a>.</li>
+   *   <li>The client connection manager is set to {@link PoolingHttpClientConnectionManager}.
+   *   <li><The retry mechanism is turned off using {@link
+   *       HttpClientBuilder#disableRedirectHandling}.
+   *   <li>The route planner uses {@link SystemDefaultRoutePlanner} with {@link
+   *       ProxySelector#getDefault()}, which uses the proxy settings from <a
+   *       href="http://docs.oracle.com/javase/7/docs/api/java/net/doc-files/net-properties.html">system
+   *       properties</a>.
    * </ul>
    *
    * @return new instance of the Apache HTTP client
    * @since 1.31
    */
   public static HttpClientBuilder newDefaultHttpClientBuilder() {
-    // Set socket buffer sizes to 8192
-    SocketConfig socketConfig =
-            SocketConfig.custom()
-                    .setRcvBufSize(8192)
-                    .setSndBufSize(8192)
-                    .build();
 
     return HttpClientBuilder.create()
-            .useSystemProperties()
-            .setSSLSocketFactory(SSLConnectionSocketFactory.getSocketFactory())
-            .setDefaultSocketConfig(socketConfig)
-            .setMaxConnTotal(200)
-            .setMaxConnPerRoute(20)
-            .setConnectionTimeToLive(-1, TimeUnit.MILLISECONDS)
-            .setRoutePlanner(new SystemDefaultRoutePlanner(ProxySelector.getDefault()))
-            .disableRedirectHandling()
-            .disableAutomaticRetries();
+        .useSystemProperties()
+        .setSSLSocketFactory(SSLConnectionSocketFactory.getSocketFactory())
+        .setMaxConnTotal(200)
+        .setMaxConnPerRoute(20)
+        .setConnectionTimeToLive(-1, TimeUnit.MILLISECONDS)
+        .setRoutePlanner(new SystemDefaultRoutePlanner(ProxySelector.getDefault()))
+        .disableRedirectHandling()
+        .disableAutomaticRetries();
   }
 
   @Override
@@ -210,4 +222,10 @@ public final class ApacheHttpTransport extends HttpTransport {
   public HttpClient getHttpClient() {
     return httpClient;
   }
+
+  /** Returns if the underlying HTTP client is mTLS. */
+  @Override
+  public boolean isMtls() {
+    return isMtls;
+  }
 }
