@@ -195,10 +195,10 @@ public class Xml {
   /**
    * Parses an XML element using the given XML pull parser into the given destination object.
    *
-   * <p>Requires the current event be {@link XmlPullParser#START_TAG} (skipping any initial
-   * {@link XmlPullParser#START_DOCUMENT}) of the element being parsed. At normal parsing
-   * completion, the current event will either be {@link XmlPullParser#END_TAG} of the element being
-   * parsed, or the {@link XmlPullParser#START_TAG} of the requested {@code atom:entry}.
+   * <p>Requires the current event be {@link XmlPullParser#START_TAG} (skipping any initial {@link
+   * XmlPullParser#START_DOCUMENT}) of the element being parsed. At normal parsing completion, the
+   * current event will either be {@link XmlPullParser#END_TAG} of the element being parsed, or the
+   * {@link XmlPullParser#START_TAG} of the requested {@code atom:entry}.
    *
    * @param parser XML pull parser
    * @param destination optional destination object to parser into or {@code null} to ignore XML
@@ -575,10 +575,10 @@ public class Xml {
     valueType = Data.resolveWildcardTypeOrTypeVariable(context, valueType);
     if (valueType == Double.class || valueType == double.class) {
       if (value.equals("INF")) {
-        return new Double(Double.POSITIVE_INFINITY);
+        return Double.valueOf(Double.POSITIVE_INFINITY);
       }
       if (value.equals("-INF")) {
-        return new Double(Double.NEGATIVE_INFINITY);
+        return Double.valueOf(Double.NEGATIVE_INFINITY);
       }
     }
     if (valueType == Float.class || valueType == float.class) {
