@@ -150,6 +150,10 @@ public class GenericUrlTest extends TestCase {
     public TestUrl(String encodedUrl) {
       super(encodedUrl);
     }
+
+    public TestUrl(String encodedUrl, boolean verbatim) {
+      super(encodedUrl, verbatim);
+    }
   }
 
   private static final String FULL =
@@ -193,6 +197,12 @@ public class GenericUrlTest extends TestCase {
     assertEquals("bar", url.foo);
   }
 
+  public void testParse_full_verbatim() {
+    TestUrl url = new TestUrl(FULL, true);
+    assertNull(url.hidden);
+    assertEquals("Go%3D%23/%25%26%20?%3Co%3Egle", url.getFirst("q"));
+  }
+
   public void testConstructor_url() throws MalformedURLException {
     GenericUrl url = new GenericUrl(new URL(FULL));
     subtestFull(url);
@@ -470,10 +480,12 @@ public class GenericUrlTest extends TestCase {
     subtestToPathParts("/path/to/resource", "", "path", "to", "resource");
     subtestToPathParts("/path/to/resource/", "", "path", "to", "resource", "");
     subtestToPathParts("/Go%3D%23%2F%25%26%20?%3Co%3Egle/2nd", "", "Go=#/%& ?<o>gle", "2nd");
+    subtestToPathParts("/plus+test/resource", "", "plus+test", "resource");
+    subtestToPathParts("/plus%2Btest/resource", "", "plus+test", "resource");
   }
 
   private void subtestToPathParts(String encodedPath, String... expectedDecodedParts) {
-    List<String> result = GenericUrl.toPathParts(encodedPath);
+    List<String> result = GenericUrl.toPathParts(encodedPath, false);
     if (encodedPath == null) {
       assertNull(result);
     } else {
